@@ -148,12 +148,12 @@ bool GetStatus(Status &status)
 
   strcpy(ifr.ifr_name,interface.c_str());
 
-  if (ioctl(handle,SIOCGIFADDR,&ifr)==0) {
+  if (ioctl(handle,SIOCGIFADDR,&ifr)>=0) {
 
     status.ip=Lum::Base::StringToWString(inet_ntoa(((struct sockaddr_in*)&ifr.ifr_addr)->sin_addr));
   }
 
-  if (ioctl(handle,SIOCGIFHWADDR,&ifr)==0) {
+  if (ioctl(handle,SIOCGIFHWADDR,&ifr)>=0) {
 
     status.mac=Lum::Base::StringToWString(ether_ntoa((ether_addr*)ifr.ifr_hwaddr.sa_data));
   }
@@ -657,7 +657,6 @@ public:
     tableModel->SetColumnWidth(2,Lum::Base::Size::stdCharWidth,15);
 
     table=new Lum::Table();
-    table->RequestFocus();
     table->SetFlex(true,true);
     table->SetModel(tableModel);
     //table->SetSelection(selection);
@@ -685,7 +684,6 @@ public:
 
     slider=new Lum::VSlider();
     slider->SetFlex(false,true);
-    slider->RequestFocus();
     slider->SetScale(true);
     slider->SetModel(refreshTime);
 
